@@ -18,7 +18,7 @@ def test_get_language_ext():
     test_lang = constants.LANGUAGES_WITH_ALIASES['all']
     for lang in test_lang:
         if ((((lang == 'executable') and (not platform._is_win))
-             or (lang in ['function', 'mpi']))):
+             or (lang in ['dummy', 'mpi']))):
             assert_raises(ValueError, languages.get_language_ext, lang)
             languages.get_language_ext(lang, default='')
         else:
