@@ -8,7 +8,7 @@ from yggdrasil.metaschema.datatypes import _schema_dir
 from yggdrasil.metaschema.datatypes.JSONObjectMetaschemaType import (
     JSONObjectMetaschemaType)
 from yggdrasil.metaschema.datatypes.PlyMetaschemaType import (
-    PlyDict,
+    trimesh, PlyDict,
     _index_type, _color_type, _coord_type,
     _index_conv, _color_conv, _coord_conv,
     _index_fmt, _color_fmt, _coord_fmt)
@@ -231,6 +231,276 @@ if not os.path.isfile(_schema_file):  # pragma: debug
 class ObjDict(PlyDict):
     r"""Enhanced dictionary class for storing Obj information."""
 
+    @classmethod
+    def from_array_dict(cls, in_dict):
+        r"""Get a version of the object from a dictionary of arrays."""
+        kws = {}
+        for k in ['material', 'vertices', 'params', 'normals', 'texcoords',
+                  'lines', 'faces', 'points', 'curves', 'curve2Ds',
+                  'surfaces']:
+            if k in in_dict:
+                kws[k] = copy.deepcopy(in_dict[k])
+        if isinstance(kws.get('vertices', None), np.ndarray):
+            old_vert = kws['vertices']
+            nvert = old_vert.shape[1]
+            assert(nvert in (3, 4))
+            kws['vertices'] = [
+                {k: old_vert[i, j] for j, k in enumerate('xyzw'[:nvert])
+                 if ((j < 3) or (not np.isnan(old_vert[i, j])))}
+                for i in range(old_vert.shape[0])]
+        if isinstance(in_dict.get('vertex_colors', None), np.ndarray):
+            old_colr = in_dict['vertex_colors']
+            assert(old_colr.shape == (len(kws['vertices']), 3))
+            for i in range(old_colr.shape[0]):
+                for j, k in enumerate(['red', 'green', 'blue']):
+                    kws['vertices'][i][k] = old_colr[i, j]
+        if isinstance(kws.get('params', None), np.ndarray):
+            old_parm = kws['params']
+            nparm = old_parm.shape[1]
+            assert(nparm in [2, 3])
+            kws['params'] = [
+                {k: old_parm[i, j] for j, k in enumerate('uvw'[:nparm])
+                 if ((j < 2) or (not np.isnan(old_parm[i, j])))}
+                for i in range(old_parm.shape[0])]
+        if isinstance(kws.get('normals', None), np.ndarray):
+            old_norm = kws['normals']
+            assert(old_norm.shape[1] == 3)
+            kws['normals'] = [
+                {k: old_norm[i, j] for j, k in enumerate('ijk')}
+                for i in range(old_norm.shape[0])]
+        if isinstance(kws.get('texcoords', None), np.ndarray):
+            old_texc = kws['texcoords']
+            ntexc = old_texc.shape[1]
+            assert(ntexc in [1, 2, 3])
+            kws['texcoords'] = [
+                {k: old_texc[i, j] for j, k in enumerate('uvw'[:ntexc])
+                 if ((j < 1) or (not np.isnan(old_texc[i, j])))}
+                for i in range(old_texc.shape[0])]
+        # Composites of above
+        if isinstance(kws.get('lines', None), np.ndarray):
+            old_edge = kws['lines']
+            assert(old_edge.shape[1] == 2)
+            kws['lines'] = [
+                [{'vertex_index': np.int32(old_edge[i, j])}
+                 for j in range(old_edge.shape[1])
+                 if (not np.isnan(old_edge[i, j]))]
+                for i in range(old_edge.shape[0])]
+        if isinstance(kws.get('faces', None), np.ndarray):
+            old_face = kws['faces']
+            assert(old_face.shape[1] >= 3)
+            kws['faces'] = [
+                [{'vertex_index': np.int32(old_face[i, j])}
+                 for j in range(old_face.shape[1])
+                 if (not np.isnan(old_face[i, j]))]
+                for i in range(old_face.shape[0])]
+        if isinstance(in_dict.get('face_texcoords', None), np.ndarray):
+            old_texc = in_dict['face_texcoords']
+            assert(old_texc.shape[0] == len(kws.get('faces', [])))
+            for i in range(old_texc.shape[0]):
+                for j in range(old_texc.shape[1]):
+                    if not np.isnan(old_texc[i, j]):
+                        kws['faces'][i][j]['texcoord_index'] = np.int32(
+                            old_texc[i, j])
+        if isinstance(in_dict.get('face_normals', None), np.ndarray):
+            old_norm = in_dict['face_normals']
+            assert(old_norm.shape[0] == len(kws.get('faces', [])))
+            for i in range(old_norm.shape[0]):
+                for j in range(old_norm.shape[1]):
+                    if not np.isnan(old_norm[i, j]):
+                        kws['faces'][i][j]['normal_index'] = np.int32(
+                            old_norm[i, j])
+        if isinstance(kws.get('points', None), np.ndarray):
+            old_pnts = kws['points']
+            kws['points'] = [
+                [np.int32(old_pnts[i, j]) for j in range(old_pnts.shape[1])
+                 if (not np.isnan(old_pnts[i, j]))]
+                for i in range(old_pnts.shape[0])]
+        if isinstance(kws.get('curves', None), np.ndarray):
+            old_curv = kws['curves']
+            kws['curves'] = [
+                {'vertex_indices': [
+                    np.int32(old_curv[i, j]) for j in range(old_curv.shape[1])
+                    if (not np.isnan(old_curv[i, j]))]}
+                for i in range(old_curv.shape[0])]
+            assert('curve_params' in in_dict)
+            if isinstance(in_dict['curve_params'], np.ndarray):
+                old_parm = in_dict['curve_params']
+                assert(old_parm.shape == (len(kws['curves']), 2))
+                for i in range(old_parm.shape[0]):
+                    kws['curves'][i]['starting_param'] = old_parm[i, 0]
+                    kws['curves'][i]['ending_param'] = old_parm[i, 1]
+        if isinstance(kws.get('curve2Ds', None), np.ndarray):
+            old_curv = kws['curve2Ds']
+            kws['curve2Ds'] = [
+                [np.int32(old_curv[i, j]) for j in range(old_curv.shape[1])
+                 if (not np.isnan(old_curv[i, j]))]
+                for i in range(old_curv.shape[0])]
+        if isinstance(kws.get('surfaces', None), np.ndarray):
+            old_surf = kws['surfaces']
+            kws['surfaces'] = [
+                {'vertex_indices': [
+                    {'vertex_index': np.int32(old_surf[i, j])}
+                    for j in range(old_surf.shape[1])
+                    if (not np.isnan(old_surf[i, j]))]}
+                for i in range(old_surf.shape[0])]
+            assert('surface_params' in in_dict)
+            if isinstance(in_dict['surface_params'], np.ndarray):
+                old_parm = in_dict['surface_params']
+                assert(old_parm.shape == (len(kws['surfaces']), 4))
+                for i in range(old_parm.shape[0]):
+                    kws['surfaces'][i]['starting_param_u'] = old_parm[i, 0]
+                    kws['surfaces'][i]['ending_param_u'] = old_parm[i, 1]
+                    kws['surfaces'][i]['starting_param_v'] = old_parm[i, 2]
+                    kws['surfaces'][i]['ending_param_v'] = old_parm[i, 3]
+        if isinstance(in_dict.get('surface_texcoords', None), np.ndarray):
+            old_texc = in_dict['surface_texcoords']
+            assert(old_texc.shape[0] == len(kws['surfaces']))
+            for i in range(old_texc.shape[0]):
+                for j in range(old_texc.shape[1]):
+                    if not np.isnan(old_texc[i, j]):
+                        kws['surfaces'][i]['vertex_indices'][j][
+                            'texcoord_index'] = np.int32(old_texc[i, j])
+        if isinstance(in_dict.get('surface_normals', None), np.ndarray):
+            old_norm = in_dict['surface_normals']
+            assert(old_norm.shape[0] == len(kws['surfaces']))
+            for i in range(old_norm.shape[0]):
+                for j in range(old_norm.shape[1]):
+                    if not np.isnan(old_norm[i, j]):
+                        kws['surfaces'][i]['vertex_indices'][j][
+                            'normal_index'] = np.int32(old_norm[i, j])
+        return cls.from_dict(kws)
+        
+    def as_array_dict(self):
+        r"""Get a version of the object as a dictionary of arrays."""
+        out = {}
+        if self.get('material', None):
+            out['material'] = self['material']
+        if self.get('vertices', None):
+            out['vertices'] = np.asarray(
+                [[v.get(k, np.NaN) for k in 'xyzw']
+                 for v in self['vertices']])
+            out['vertex_colors'] = np.asarray(
+                [[v.get(k, np.NaN) for k in ['red', 'green', 'blue']]
+                 for v in self['vertices']])
+            if np.all(np.isnan(out['vertices'][:, 3])):
+                out['vertices'] = out['vertices'][:, :3]
+            if np.all(np.isnan(out['vertex_colors'])):
+                out.pop('vertex_colors')
+        if self.get('params', None):
+            out['params'] = np.asarray(
+                [[v.get(k, np.NaN) for k in 'uvw']
+                 for v in self['params']])
+            if np.all(np.isnan(out['params'][:, 2])):
+                out['params'] = out['params'][:, :2]
+        if self.get('normals', None):
+            out['normals'] = np.asarray(
+                [[v[k] for k in 'ijk'] for v in self['normals']])
+        if self.get('texcoords', None):
+            out['texcoords'] = np.asarray(
+                [[v.get(k, np.NaN) for k in 'uvw']
+                 for v in self['texcoords']])
+            if np.all(np.isnan(out['texcoords'][:, 1:])):
+                out['texcoords'] = out['texcoords'][:, :1]
+            elif np.all(np.isnan(out['texcoords'][:, 2])):
+                out['texcoords'] = out['texcoords'][:, :2]
+        if self.get('lines', None):
+            out['lines'] = np.NaN * np.ones(
+                (len(self['lines']), len(max(self['lines'], key=len))),
+                dtype='int32')
+            for i, vlist in enumerate(self['lines']):
+                for j, v in enumerate(vlist):
+                    out['lines'][i, j] = v['vertex_index']
+        if self.get('faces', None):
+            face_shp = (len(self['faces']), len(max(self['faces'], key=len)))
+            out['faces'] = np.NaN * np.ones(face_shp, dtype='int32')
+            out['face_texcoords'] = np.NaN * np.ones(face_shp, dtype='int32')
+            out['face_normals'] = np.NaN * np.ones(face_shp, dtype='int32')
+            for i, vlist in enumerate(self['faces']):
+                for j, v in enumerate(vlist):
+                    out['faces'][i, j] = v['vertex_index']
+                    out['face_texcoords'][i, j] = v.get(
+                        'texcoord_index', np.NaN)
+                    out['face_normals'][i, j] = v.get('normal_index', np.NaN)
+            if np.all(np.isnan(out['face_texcoords'])):
+                out.pop('face_texcoords')
+            if np.all(np.isnan(out['face_normals'])):
+                out.pop('face_normals')
+        if self.get('points', None):
+            out['points'] = np.NaN * np.ones(
+                (len(self['points']), len(max(self['points'], key=len))),
+                dtype='int32')
+            for i, vlist in enumerate(self['points']):
+                out['points'][i, :len(vlist)] = vlist
+        if self.get('curves', None):
+            def fkey(x):
+                return len(x['vertex_indices'])
+            out['curves'] = np.NaN * np.ones(
+                (len(self['curves']), len(max(self['curves'], key=fkey))),
+                dtype='int32')
+            out['curve_params'] = np.zeros((out['curves'].shape[0], 2))
+            for i, curv in enumerate(self['curves']):
+                out['curve_params'][i, :] = [curv['starting_param'],
+                                             curv['ending_param']]
+                out['curves'][i, :fkey(curv)] = curv['vertex_indices']
+        if self.get('curve2Ds', None):
+            out['curve2Ds'] = np.NaN * np.ones(
+                (len(self['curve2Ds']), len(max(self['curve2Ds'], key=len))),
+                dtype='int32')
+            for i, vlist in enumerate(self['curve2Ds']):
+                out['curve2Ds'][i, :len(vlist)] = vlist
+        if self.get('surfaces', None):
+            def fkey(x):
+                return len(x['vertex_indices'])
+            surf_shp = (len(self['surfaces']), len(max(self['surfaces'], key=fkey)))
+            out['surfaces'] = np.NaN * np.ones(surf_shp, dtype='int32')
+            out['surface_params'] = np.zeros((surf_shp[0], 4))
+            out['surface_texcoords'] = np.NaN * np.ones(surf_shp, dtype='int32')
+            out['surface_normals'] = np.NaN * np.ones(surf_shp, dtype='int32')
+            for i, surf in enumerate(self['surfaces']):
+                out['surface_params'][i, :] = [surf['starting_param_u'],
+                                               surf['ending_param_u'],
+                                               surf['starting_param_v'],
+                                               surf['ending_param_v']]
+                for j, v in enumerate(surf['vertex_indices']):
+                    out['surfaces'][i, j] = v['vertex_index']
+                    out['surface_texcoords'][i, j] = v.get(
+                        'texcoord_index', np.NaN)
+                    out['surface_normals'][i, j] = v.get(
+                        'normal_index', np.NaN)
+            if np.all(np.isnan(out['surface_texcoords'])):
+                out.pop('surface_texcoords')
+            if np.all(np.isnan(out['surface_normals'])):
+                out.pop('surface_normals')
+        return out
+    
+    @classmethod
+    def from_trimesh(cls, in_mesh):
+        r"""Get a version of the object from a trimesh class."""
+        kws = dict(vertices=in_mesh.vertices,
+                   vertex_colors=in_mesh.visual.vertex_colors,
+                   faces=in_mesh.faces.astype('int32'))
+        weights = (kws['vertex_colors'][:, 3].astype('float32') + 1.0) / 256
+        weights[weights == 1.0] = np.NaN
+        kws['vertex_colors'] = kws['vertex_colors'][:, :3]
+        kws['vertices'] = np.hstack([kws['vertices'], weights[..., None]])
+        return cls.from_array_dict(kws)
+
+    def as_trimesh(self, **kwargs):
+        r"""Get a version of the object as a trimesh class."""
+        kws0 = self.as_array_dict()
+        kws = {'vertices': kws0.get('vertices', None),
+               'vertex_colors': kws0.get('vertex_colors', None),
+               'faces': kws0.get('faces', None)}
+        if (kws['vertices'] is not None) and (kws['vertices'].shape[1] == 4):
+            weights = kws['vertices'][:, 3] * 256 - 1.0
+            weights[np.isnan(weights)] = 255
+            kws['vertices'] = kws['vertices'][:, :3]
+            if kws['vertex_colors'] is not None:
+                kws['vertex_colors'] = np.hstack(
+                    [kws['vertex_colors'], weights[..., None]])
+        kws.update(kwargs, process=False)
+        return trimesh.base.Trimesh(**kws)
+    
     @property
     def mesh(self):
         r"""list: Vertices for each face in the structure."""
@@ -456,6 +726,12 @@ class ObjDict(PlyDict):
         return super(ObjDict, self).apply_scalar_map(*args, **kwargs)
     
 
+if trimesh:
+    python_types = (dict, ObjDict, trimesh.base.Trimesh)
+else:
+    python_types = (dict, ObjDict)
+
+   
 # The base class could be anything since it is discarded during registration,
 # but is set to JSONObjectMetaschemaType here for transparancy since this is
 # what the base class is determined to be on loading the schema
@@ -463,7 +739,7 @@ class ObjMetaschemaType(JSONObjectMetaschemaType):
     r"""Obj 3D structure map."""
 
     _empty_msg = {'vertices': [], 'faces': []}
-    python_types = (dict, ObjDict)
+    python_types = python_types
     schema_file = _schema_file
     _replaces_existing = False
 
@@ -560,6 +836,8 @@ class ObjMetaschemaType(JSONObjectMetaschemaType):
             bytes, str: Serialized message.
 
         """
+        if trimesh and isinstance(obj, trimesh.base.Trimesh):
+            obj = ObjDict.from_trimesh(obj)
         # Encode header
         header = ['# Author ygg_auto',
                   '# Generated by yggdrasil']
@@ -650,10 +928,12 @@ class ObjMetaschemaType(JSONObjectMetaschemaType):
             object: Coerced object.
 
         """
+        if trimesh and isinstance(obj, trimesh.base.Trimesh):
+            obj = ObjDict.from_trimesh(obj)
         if isinstance(obj, dict) and ('material' in obj):
             obj['material'] = tools.bytes2str(obj['material'])
-        return super(ObjMetaschemaType, cls).coerce_type(obj, typedef=typedef,
-                                                         **kwargs)
+        return super(ObjMetaschemaType, cls).coerce_type(
+            obj, typedef=typedef, **kwargs)
 
     @classmethod
     def updated_fixed_properties(cls, obj):
