@@ -28,9 +28,14 @@ class YggFunction(YggClass):
     r"""This class wraps function-like behavior around a model.
 
     Args:
-        model_yaml (str, list): Full path to one or more yaml files containing
-            model information including the location of the source code and any
-            input(s)/output(s).
+        model_yaml (str, list): Full path to one or more YAML specification
+            files containing information defining a partial integration. If
+            service_address is set, this should be the name of a service
+            registered with the service manager running at the provided
+            address.
+        service_address (str, optional): Address for service manager that is
+            capable of running the specified integration. Defaults to None
+            and is ignored.
         **kwargs: Additional keyword arguments are passed to the YggRunner
             constructor.
 
@@ -41,17 +46,28 @@ class YggFunction(YggClass):
 
     """
     
-    def __init__(self, model_yaml, **kwargs):
+    def __init__(self, model_yaml, service_address=None, **kwargs):
+        import uuid
         from yggdrasil.languages.Python.YggInterface import (
             YggInput, YggOutput, YggRpcClient)
         super(YggFunction, self).__init__()
         # Create and start runner in another process
-        self.runner = YggRunner(model_yaml, as_function=True, **kwargs)
+        self.dummy_name = 'func' + str(uuid.uuid4()).split('-')[0]
+        kwargs['complete_partial'] = self.dummy_name
+        if service_address:
+            # Temporary YAML describing the service
+            contents = (f'service:\n'
+                        f'    name: {model_yaml}\n'
+                        f'    address: {service_address}\n')
+            model_yaml = os.path.join(os.getcwd(), self.dummy_name + '.yml')
+            with open(model_yaml, 'w') as fd:
+                fd.write(contents)
+        self.runner = YggRunner(model_yaml, **kwargs)
         # Start the drivers
         self.runner.run()
-        self.model_driver = self.runner.modeldrivers['function_model']
+        self.model_driver = self.runner.modeldrivers[self.dummy_name]
         for k in self.runner.modeldrivers.keys():
-            if k != 'function_model':
+            if k != self.dummy_name:
                 self.__name__ = k
                 break
         self.debug("run started")
@@ -118,6 +134,8 @@ class YggFunction(YggClass):
             self.returns += v['vars']
         self.debug("arguments: %s, returns: %s", self.arguments, self.returns)
         self.runner.pause()
+        if service_address:
+            os.remove(model_yaml)
 
     # def widget_function(self, *args, **kwargs):
     #     # import matplotlib.pyplot as plt
@@ -187,13 +205,12 @@ class YggFunction(YggClass):
         self._stop_called = True
         for x in self.inputs.values():
             x['comm'].send_eof()
-            x['comm'].linger_close()
-        for x in self.outputs.values():
-            x['comm'].close()
-        self.model_driver['instance'].terminate()
+        self.model_driver['instance'].set_break_flag()
         self.runner.waitModels(timeout=10)
         for x in self.inputs.values():
             x['comm'].close()
+        for x in self.outputs.values():
+            x['comm'].close()
         self.runner.terminate()
         self.runner.atexit()
         os.environ.clear()
@@ -204,7 +221,7 @@ class YggFunction(YggClass):
         print("Models: %s\nInputs:\n%s\nOutputs:\n%s\n"
               % (', '.join([x['name'] for x in
                             self.runner.modeldrivers.values()
-                            if x['name'] != 'function_model']),
+                            if x['name'] != self.dummy_name]),
                  '\n'.join(['\t%s (vars=%s)' % (k, v['vars'])
                             for k, v in self.inputs.items()]),
                  '\n'.join(['\t%s (vars=%s)' % (k, v['vars'])
@@ -231,8 +248,15 @@ class YggRunner(YggClass):
             Defaults to environment variable 'RMQ_DEBUG'.
         ygg_debug_prefix (str, optional): Prefix for Ygg debug messages.
             Defaults to namespace.
-        as_function (bool, optional): If True, the missing input/output channels
-            will be created for using model(s) as a function. Defaults to False.
+        as_service (bool, optional): If True, the integration is running as a
+            service. If True, complete_partial is set to True. Defaults to
+            False.
+        complete_partial (bool, optional): If True, unpaired input/output
+            channels are allowed and reserved for use (e.g. for calling the
+            model as a function). Defaults to False.
+        partial_commtype (dict, optional): Communicator kwargs that should be
+            be used for the connections to the unpaired channels when
+            complete_partial is True. Defaults to None and will be ignored.
 
     Attributes:
         namespace (str): Name that should be used to uniquely identify any RMQ
@@ -250,7 +274,8 @@ class YggRunner(YggClass):
     def __init__(self, modelYmls, namespace=None, host=None, rank=0,
                  ygg_debug_level=None, rmq_debug_level=None,
                  ygg_debug_prefix=None, connection_task_method='thread',
-                 as_function=False, production_run=False,
+                 as_service=False, complete_partial=False,
+                 partial_commtype=None, production_run=False,
                  mpi_tag_start=None):
         self.mpi_comm = None
         name = 'runner'
@@ -265,6 +290,8 @@ class YggRunner(YggClass):
             namespace = ygg_cfg.get('rmq', 'namespace', False)
         if not namespace:  # pragma: debug
             raise Exception('rmq:namespace not set in config file')
+        if as_service:
+            complete_partial = True
         self.namespace = namespace
         self.host = host
         self.rank = rank
@@ -277,7 +304,8 @@ class YggRunner(YggClass):
         self._old_handlers = {}
         self.production_run = production_run
         self.error_flag = False
-        self.as_function = as_function
+        self.complete_partial = complete_partial
+        self.partial_commtype = partial_commtype
         self.debug("Running in %s with path %s namespace %s rank %d",
                    os.getcwd(), sys.path, namespace, rank)
         # Update environment based on config
@@ -287,9 +315,21 @@ class YggRunner(YggClass):
         if self.mpi_comm and (self.rank > 0):
             pass
         else:
-            self.drivers = yamlfile.parse_yaml(modelYmls, as_function=as_function)
+            self.drivers = yamlfile.parse_yaml(
+                modelYmls, complete_partial=complete_partial,
+                partial_commtype=partial_commtype)
             self.connectiondrivers = self.drivers['connection']
             self.modeldrivers = self.drivers['model']
+            for x in self.modeldrivers.values():
+                if x['driver'] == 'DummyModelDriver':
+                    x['runner'] = self
+                    if as_service:
+                        for io in x['output_drivers']:
+                            for comm in io['inputs']:
+                                comm['for_service'] = True
+                        for io in x['input_drivers']:
+                            for comm in io['outputs']:
+                                comm['for_service'] = True
 
     def pprint(self, *args):
         r"""Print with color."""
@@ -344,11 +384,12 @@ class YggRunner(YggClass):
         """
         if signal_handler is None:
             signal_handler = self.signal_handler
-        self._swap_handler(signal.SIGINT, signal_handler)
-        if not platform._is_win:
-            self._swap_handler(signal.SIGTERM, signal_handler)
-        else:  # pragma: windows
-            self._swap_handler(signal.SIGBREAK, signal_handler)
+        if signal_handler:
+            self._swap_handler(signal.SIGINT, signal_handler)
+            if not platform._is_win:
+                self._swap_handler(signal.SIGTERM, signal_handler)
+            else:  # pragma: windows
+                self._swap_handler(signal.SIGBREAK, signal_handler)
 
     def reset_signal_handler(self):
         r"""Reset signal handlers to old ones."""
@@ -384,7 +425,7 @@ class YggRunner(YggClass):
             self.startDrivers()
             times['start drivers'] = timer()
             self.set_signal_handler(signal_handler)
-            if not self.as_function:
+            if not self.complete_partial:
                 self.waitModels()
                 times['run models'] = timer()
                 self.atexit()
@@ -774,6 +815,15 @@ class YggRunner(YggClass):
             self.mpi_comm.barrier()
         self.debug('ALL DRIVERS STARTED')
 
+    @property
+    def is_alive(self):
+        r"""bool: True if all of the models are still running, False
+        otherwise."""
+        for drv in self.modeldrivers.values():
+            if (not drv['instance'].is_alive()) or drv['instance'].errors:
+                return False
+        return True
+
     def waitModels(self, timeout=False):
         r"""Wait for all model drivers to finish. When a model finishes,
         join the thread and perform exits for associated IO drivers."""
@@ -908,12 +958,16 @@ class YggRunner(YggClass):
         # self.outputdrivers = {}
         # self.modeldrivers = {}
 
-    def printStatus(self):
+    def printStatus(self, return_str=False):
         r"""Print the status of all drivers, starting with the IO drivers."""
         self.debug('')
+        out = []
         for driver in self.all_drivers:
             if 'instance' in driver:
-                driver['instance'].printStatus()
+                out.append(
+                    driver['instance'].printStatus(return_str=return_str))
+        if return_str:
+            return '\n'.join(out)
 
     def closeChannels(self, force_stop=False):
         r"""Stop IO drivers and join the threads.
